SerialPortXonXoff enum
Values
- disabled → const SerialPortXonXoff
-
XON/XOFF disabled.
const SerialPortXonXoff(sp_xonxoff.DISABLED) - input → const SerialPortXonXoff
-
XON/XOFF enabled for input only.
const SerialPortXonXoff(sp_xonxoff.IN) - output → const SerialPortXonXoff
-
XON/XOFF enabled for output only.
const SerialPortXonXoff(sp_xonxoff.OUT) - inputOutput → const SerialPortXonXoff
-
XON/XOFF enabled for input and output.
const SerialPortXonXoff(sp_xonxoff.INOUT)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
int value) → SerialPortXonXoff?
Constants
-
values
→ const List<
SerialPortXonXoff> - A constant List of the values in this enum, in order of their declaration.