SerialPortInfo class
Constructors
- SerialPortInfo({required String name, required String description, required SerialPortTransport transport, required int? usbBus, required int? usbAddress, required int? usbVid, required int? usbPid, required String? usbManufacturer, required String? usbProduct, required String? usbSerialNumber, required String? bluetoothAddress})
-
const
Properties
- bluetoothAddress → String?
-
final
- description → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited - transport → SerialPortTransport
-
final
- usbAddress → int?
-
final
- usbBus → int?
-
final
- usbManufacturer → String?
-
final
- usbPid → int?
-
final
- usbProduct → String?
-
final
- usbSerialNumber → String?
-
final
- usbVid → int?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String - A string representation of this object.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited